Welcome to the API documet site for the micro-python SenML library.

The following api sections are available:

- [senml-base](./senml_base): the base class for all senml objects.
- [senml-pack](./senml_pack): the class that represents root documents.
- [senml-record](./senml_record): the class that stores sensor measurements
- [senml-unit](./senml_unit): the list of all unit names that can be used.



Copyright (c) 2018 KPN
Copyright (c) 2023 MicroPython
